@@ -6,9 +6,11 @@ import unittest
 
 class TestSanity(unittest.TestCase):
     def setUp(self):
-        self.help_output = subprocess.check_output(["makedumpfile", "-h"]).decode()
+        self.help_output = subprocess.check_output(
+            ["/usr/bin/makedumpfile", "-h"]
+        ).decode()
         self.ldd_output = subprocess.check_output(
-            ["ldd", "makedumpfile"]
+            ["ldd", "/usr/bin/makedumpfile"]
         ).decode()
 
     def test_lzo(self):
